@@ -28,6 +28,9 @@ def normalize_path(queuepath):
     return "fq://" + toabs(queuepath)
   return queuepath
 
+def intify(x):
+  return None if x is None else int(x)
+
 class Tuple3(click.ParamType):
   """A command line option type consisting of 3 comma-separated integers."""
   name = 'tuple3'
@@ -56,7 +59,7 @@ class Tuple2(click.ParamType):
 
 @click.group()
 @click.option("-p", "--parallel", default=1, help="Run with this number of parallel processes. If 0, use number of cores.")
-@click.version_option(version="4.5.4")
+@click.version_option(version="4.5.5")
 @click.pass_context
 def main(ctx, parallel):
   """
@@ -428,8 +431,8 @@ def ccl_faces(
   src = cloudfiles.paths.normalize(src)
   tasks = tc.create_ccl_face_tasks(
     src, mip, shape,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
 
@@ -455,8 +458,8 @@ def ccl_equivalences(
   src = cloudfiles.paths.normalize(src)
   tasks = tc.create_ccl_equivalence_tasks(
     src, mip, shape,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
 
@@ -501,8 +504,8 @@ def ccl_relabel(
     src, dest, 
     mip=mip, shape=shape, 
     chunk_size=chunk_size, encoding=encoding,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
 
@@ -551,8 +554,8 @@ def ccl_auto(
 
   tasks = tc.create_ccl_face_tasks(
     src, mip, shape,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
   tq.insert(tasks, parallel=parallel)
@@ -560,8 +563,8 @@ def ccl_auto(
 
   tasks = tc.create_ccl_equivalence_tasks(
     src, mip, shape,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
   tq.insert(tasks, parallel=parallel)
@@ -574,8 +577,8 @@ def ccl_auto(
     src, dest, 
     mip=mip, shape=shape, 
     chunk_size=chunk_size, encoding=encoding,
-    threshold_lte=int(threshold_lte),
-    threshold_gte=int(threshold_gte),
+    threshold_lte=intify(threshold_lte),
+    threshold_gte=intify(threshold_gte),
     fill_missing=fill_missing,
   )
   tq.insert(tasks, parallel=parallel)
